==> adsprod-facade-3.2.17-sources.jar: com/bxm/adsprod/facade/ticket/TicketTemplateAssetsConfig.java <==
package com.bxm.adsprod.facade.ticket;

import java.io.Serializable;

/**
 * 模板素材里具体素材内容.</br>
 * @author zhengwangeng
 * @date 2021/6/11.
 */
public class TicketTemplateAssetsConfig implements Serializable {

    private static final long serialVersionUID = 1733401522239243683L;

    /**
     * 广告标题
     */
    private String title;

    /**
     * 广告内容
     */
    private String content;

    /**
     * APP名称/广告来源
     */
    private String originName;

    /**
     * 按钮内容
     */
    private String buttonText;

    /**
     * 广告Icon
     */
    private String icon;

    /**
     * 图片
     */
    private String image;

    /**
     * 封面/结束图
     */
    private String coverOrEndImage;

    /**
     * Banner图
     */
    private String bannerImage;

    /**
     * 视频内容
     */
    private String video;

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getOriginName() {
        return originName;
    }

    public void setOriginName(String originName) {
        this.originName = originName;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getCoverOrEndImage() {
        return coverOrEndImage;
    }

    public void setCoverOrEndImage(String coverOrEndImage) {
        this.coverOrEndImage = coverOrEndImage;
    }

    public String getBannerImage() {
        return bannerImage;
    }

    public void setBannerImage(String bannerImage) {
        this.bannerImage = bannerImage;
    }

    public String getVideo() {
        return video;
    }

    public void setVideo(String video) {
        this.video = video;
    }
}

==> adsprod-facade-3.3.15.15-sources.jar: com/bxm/adsprod/facade/ticket/TicketTemplateAssetsConfig.java <==
package com.bxm.adsprod.facade.ticket;

import java.io.Serializable;

/**
 * 模板素材里具体素材内容.</br>
 * @author zhengwangeng
 * @date 2021/6/11.
 */
public class TicketTemplateAssetsConfig implements Serializable {

    private static final long serialVersionUID = 1733401522239243683L;

    /**
     * 广告标题
     */
    private String title;

    /**
     * 广告内容
     */
    private String content;

    /**
     * APP名称/广告来源
     */
    private String originName;

    /**
     * 按钮内容
     */
    private String buttonText;

    /**
     * 广告Icon
     */
    private String icon;

    /**
     * 图片
     */
    private String image;

    /**
     * 封面/结束图
     */
    private String coverOrEndImage;

    /**
     * Banner图
     */
    private String bannerImage;

    /**
     * 视频内容
     */
    private String video;

    /**
     * 视频结束页返回拦截图
     */
    private String interceptImage;

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getOriginName() {
        return originName;
    }

    public void setOriginName(String originName) {
        this.originName = originName;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getCoverOrEndImage() {
        return coverOrEndImage;
    }

    public void setCoverOrEndImage(String coverOrEndImage) {
        this.coverOrEndImage = coverOrEndImage;
    }

    public String getBannerImage() {
        return bannerImage;
    }

    public void setBannerImage(String bannerImage) {
        this.bannerImage = bannerImage;
    }

    public String getVideo() {
        return video;
    }

    public void setVideo(String video) {
        this.video = video;
    }

    public String getInterceptImage() {
        return interceptImage;
    }

    public void setInterceptImage(String interceptImage) {
        this.interceptImage = interceptImage;
    }
}
